Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6521)

Unified Diff: chrome/browser/ui/cocoa/bubble_anchor_helper_views.h

Issue 2882533003: [Mac] Hover/Active Omnibox Icon States for Secondary UI MD (Closed)
Patch Set: Rebased and applied tapted's changes Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/bubble_anchor_helper_views.h
diff --git a/chrome/browser/ui/cocoa/bubble_anchor_helper_views.h b/chrome/browser/ui/cocoa/bubble_anchor_helper_views.h
index 527c5ceb187a1bfff42b85cb3adfd6255293b4a5..9598a3eae40ee243a82fb14aecaeeac8bb3e14ba 100644
--- a/chrome/browser/ui/cocoa/bubble_anchor_helper_views.h
+++ b/chrome/browser/ui/cocoa/bubble_anchor_helper_views.h
@@ -9,8 +9,17 @@ namespace views {
class BubbleDialogDelegateView;
}
+class LocationBarDecoration;
+
+// Returns the manage password icon decoration in the omnibox.
+LocationBarDecoration* GetManagePasswordDecoration(
+ views::BubbleDialogDelegateView* bubble);
+
// Monitors |bubble|'s parent window for size changes, and updates the bubble
-// anchor. The monitor will be deleted when |bubble| is closed.
-void KeepBubbleAnchored(views::BubbleDialogDelegateView* bubble);
+// anchor. The monitor will be deleted when |bubble| is closed. If |decoration|
+// is provided, the decoration will be set to active in this function. It will
+// be set to inactive when |bubble| is closed.
+void KeepBubbleAnchored(views::BubbleDialogDelegateView* bubble,
+ LocationBarDecoration* decoration = nullptr);
#endif // CHROME_BROWSER_UI_COCOA_BUBBLE_ANCHOR_HELPER_VIEWS_H_
« no previous file with comments | « chrome/browser/ui/cocoa/browser_window_controller.mm ('k') | chrome/browser/ui/cocoa/bubble_anchor_helper_views.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698